/*
 * $Id: vtt.h,v 1.8 1996/04/28 18:17:38 vons Exp $
 *
 * Global vtt include file, contains vtt's defaults and the prototypes
 * for the internal functions.
 */

#include <stdlib.h>               /* size_t */
#include <stdio.h>                /* FILE * */

#include <assert.h>

#ifdef __STDC__
#undef PROTO				/* just in case */
#define PROTO
#endif

#ifdef PROTO
#define PROTOTYPE(func, arglist)  func arglist
#else
#define PROTOTYPE(func, arglist)  func ()
#endif

#ifndef HAVE_SSIZE_T
typedef int ssize_t;
#endif

#define VTT_USER_TERMTAB   ".vtt_termtab"

#define VTT_SYSTEM_TERMTAB "/usr/local/etc/vtt_termtab"

#define VTT_MAX_LINELEN	   128

#define VTT_DFLT_TIMEOUT   10     /* one second */

#define VTT_DFLT_TERMTYPE  "dumb"

typedef unsigned char Uchar;

/*
 * Type for global option struct. Note that not all options are actually
 * in here!
 */
struct opts
{
    int       dump_queries;       /* print queries & keywords */
    int       trace;              /* show trace of .vtt_termtab processing */
    int       verbose;            /* when finished, print verbose tty name
                                   * to stderr */
    int       quiet;              /* don't complain if term is not
                                   * recognised */
    int       skip_unknown_ttys;  /* don't test unsupported terminals */
    int       no_init;		  /* don't send tty's init string */
    int       dont_set_keys;	  /* don't set tty's special keys */
    const char *setenv_str;	  /* fmt str for env setup */
};

/*----------------------------------------------------------------------
 * main.c
 */
extern struct opts globopt;

/*----------------------------------------------------------------------
 * capinfo.c
 */
enum CI_result
{
    CI_ok, CI_invalid
};

PROTOTYPE(enum CI_result ci_test, (const char *tty_name));
PROTOTYPE(void ci_setup_env, (const char *tty_name));
PROTOTYPE(void ci_send_init_string, (void));
PROTOTYPE(void ci_init_tty_keys, (void));

/*----------------------------------------------------------------------
 * support.c
 */
PROTOTYPE(void setprocessname, (const char *argv0));
PROTOTYPE(const char *getprocessname, (void));
PROTOTYPE(void *memdup, (const void *src, size_t len, size_t extra));
PROTOTYPE(void strtoupper, (char *str));

#ifndef HAVE_STRERROR
PROTOTYPE(extern char *strerror, (int errnum));
#endif

/* Flags for act arg of pr_error(), will exit when PR_FATAL is passed */
#define PR_FATAL	1
#define PR_WARN		2

#ifdef HAVE_WORKING_STDARG
PROTOTYPE(void pr_error, (int act, const char *fmt,...));
PROTOTYPE(void pr_verbose, (const char *fmt,...));
PROTOTYPE(void pr_trace, (const char *fmt,...));

#else                             /* !HAVE_WORKING_STDARG */

PROTOTYPE(void pr_error, ());
PROTOTYPE(void pr_verbose, ());
PROTOTYPE(void pr_trace, ());

#endif                            /* !HAVE_WORKING_STDARG */

/*----------------------------------------------------------------------
 * tty.c
 */
PROTOTYPE(void tty_verify, (void));
PROTOTYPE(void tty_raw, (void));
PROTOTYPE(void tty_restore, (void));
PROTOTYPE(int  tty_readchar, (void));
PROTOTYPE(void tty_write, (const Uchar * buf, size_t len));
PROTOTYPE(void tty_set_erase_key, (int key));

/*----------------------------------------------------------------------
 * termtab.c
 */

enum TT_result
{
    TT_recognised, TT_failed
};

PROTOTYPE(void tt_ignore_usertab, (void));
PROTOTYPE(void tt_init, (const char *termtab_name));
PROTOTYPE(void tt_exit, (void));
PROTOTYPE(enum TT_result tt_process, (char **ttytype, char **ttydesc));
PROTOTYPE(char *tt_cook, (const Uchar * rawstr, size_t rawlen));

/*----------------------------------------------------------------------
 * query.c
 */

PROTOTYPE(void query_settimeout, (int t));
PROTOTYPE(void query_add, (const char *qid, const Uchar * qstr, size_t qlen));
PROTOTYPE(void query, (const char *qid, const Uchar ** ans, size_t *anslen));
PROTOTYPE(void query_dump, (void));

/*----------------------------------------------------------------------
 * parse.c
 */

/* outcome of a function, ok, end of line, end of file, or failure */
enum PA_result
{
    PA_ok, PA_eol, PA_eof, PA_fail
};

/* what to do if leading whitespace is found, skip it or fail */
enum PA_wsp
{
    PA_wsp_skip, PA_wsp_fail
};

/* Supported operators as returned by pa_getcond */
enum PA_ops
{
    PA_op_equal, PA_op_unequal
};

PROTOTYPE(void pa_setinput, (FILE *fp));
PROTOTYPE(enum PA_result pa_nextline, (void));
PROTOTYPE(void pa_restart_line, (void));
PROTOTYPE(int pa_lineno, (void));

PROTOTYPE(char *pa_getline, (enum PA_wsp allow_wsp));
PROTOTYPE(enum PA_result pa_getword, (enum PA_wsp wsp, char **wrd));
PROTOTYPE(enum PA_result pa_findchar, (enum PA_wsp wsp, int ch));
PROTOTYPE(enum PA_result pa_getoperator, (enum PA_wsp wsp, enum PA_ops * oper));

PROTOTYPE(enum PA_result pa_getstr,
          (enum PA_wsp wsp, Uchar ** str, size_t *slen));
